==> dclib-0.3.18.tar.bz2: dclib-0.3.18/dclib/core/cssl.h <==
/***************************************************************************
                          cssl.h  -  description
                             -------------------
    begin                : Sat Dec 7 2002
    copyright            : (C) 2002-2003 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CSSL_H
#define CSSL_H

/**
  *@author Mathias Kster
  */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <dclib/dcos.h>
#include <dclib/core/cobject.h>

/*
 * It appears to be impossible to forward declare the SSL objects because they
 * are defined using typedef.
 */
#include <dclib/dclib-ssl-use.h>

#if DCLIB_USES_OPENSSL == 1

#include <openssl/opensslv.h>
#include <openssl/rsa.h>
#include <openssl/rand.h>
#include <openssl/evp.h>
#include <openssl/ssl.h>
#include <openssl/err.h>

#else

#ifndef RSA
#define RSA void
#endif
#ifndef SSL_CTX
#define SSL_CTX void
#endif

#endif

class DLL_EXPORT CSSLObject : public CObject {
public:
	/** */
	CSSLObject() {
		m_bHandshakeState = 0;
		m_pRSA            = 0;
	};
	/** */
	virtual ~CSSLObject();

	/** */
	int m_bHandshakeState;
	/* */
	RSA * m_pRSA;
	/** */
	unsigned char m_localkey[16];
	/** */
	unsigned char m_localiv[8];
	/** */
	unsigned char m_remotekey[16];
	/** */
	unsigned char m_remoteiv[8];
};

class DLL_EXPORT CSSL : public CObject {
public:
	/** */
	CSSL();
	/** */
	virtual ~CSSL();

	/** */
	SSL_CTX * InitClientCTX();
	/** */
	SSL_CTX * InitServerCTX();
	/** */
	bool LoadCertificates( SSL_CTX * ctx, char * CertFile, char * KeyFile );
	/** Get SSL library version string */
	static CString GetSSLVersionString();

protected:
	/** */
	void InitRand();
	/** */
	void InitRandArray( unsigned char * a, int len );
	/** */
	bool GenerateRsaKey();
	/** */
	CString GetPublicRsaKey();
	/** */
	bool SetPublicKey( CSSLObject * SSLObject, CString s );
	/** */
	void InitSessionKey( CSSLObject * SSLObject );
	/** */
	CString GetSessionKey( CSSLObject * SSLObject );
	/** */
	bool SetSessionKey( CSSLObject * SSLObject, CString s );
	/** */
	CString EncryptData( CSSLObject * SSLObject, CString s );
	/** */
	CString DecryptData( CSSLObject * SSLObject, CString s );

	/* */
	RSA * m_pRSA;
	/** */
	int * m_pRandBuffer;
};

#endif

==> dclib-0.3.21.tar.bz2: dclib-0.3.21/dclib/core/cssl.h <==
/***************************************************************************
                          cssl.h  -  description
                             -------------------
    begin                : Sat Dec 7 2002
    copyright            : (C) 2002-2003 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CSSL_H
#define CSSL_H

/**
  *@author Mathias Kster
  */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <dclib/dcos.h>
#include <dclib/core/cstring.h>

/*
 * It appears to be impossible to forward declare the SSL objects because they
 * are defined using typedef.
 */
#include <dclib/dclib-ssl-use.h>

#if DCLIB_USES_OPENSSL == 1

#include <openssl/opensslv.h>
#include <openssl/rsa.h>
#include <openssl/rand.h>
#include <openssl/evp.h>
#include <openssl/ssl.h>
#include <openssl/err.h>

#else

#ifndef RSA
#define RSA void
#endif
#ifndef SSL_CTX
#define SSL_CTX void
#endif

#endif

class DLL_EXPORT CSSLObject {
public:
	/** */
	CSSLObject() {
		m_bHandshakeState = 0;
		m_pRSA            = 0;
	};
	/** */
	~CSSLObject();

	/** */
	int m_bHandshakeState;
	/* */
	RSA * m_pRSA;
	/** */
	unsigned char m_localkey[16];
	/** */
	unsigned char m_localiv[8];
	/** */
	unsigned char m_remotekey[16];
	/** */
	unsigned char m_remoteiv[8];
};

class DLL_EXPORT CSSL {
public:
	/** */
	CSSL();
	/** */
	virtual ~CSSL();

	/** */
	static SSL_CTX * InitClientCTX();
	/** */
	static SSL_CTX * InitServerCTX();
	/**
	 * As the name suggests it creates a new client SSL_CTX
	 * that only supports >= TLSv1, required for
	 * *DC++ compatibility.
	 */
	static SSL_CTX * NewTLSv1ClientCTX();
	/**
	 * As the name suggests it creates a new server SSL_CTX
	 * that only supports >= TLSv1, required for
	 * *DC++ compatibility.
	 */
	static SSL_CTX * NewTLSv1ServerCTX();
	/** */
	static bool LoadCertificates( SSL_CTX * ctx, char * CertFile, char * KeyFile );
	/** Get SSL library version string */
	static CString GetSSLVersionString();
	/** Perform library initialisation functions */
	static void InitSSLLibrary();
	/** Perform library deinitialisation functions */
	static void DeInitSSLLibrary();

protected:
	/** */
	void InitRand();
	/** */
	void InitRandArray( unsigned char * a, int len );
	/** */
	bool GenerateRsaKey();
	/** */
	CString GetPublicRsaKey();
	/** */
	bool SetPublicKey( CSSLObject * SSLObject, CString s );
	/** */
	void InitSessionKey( CSSLObject * SSLObject );
	/** */
	CString GetSessionKey( CSSLObject * SSLObject );
	/** */
	bool SetSessionKey( CSSLObject * SSLObject, CString s );
	/** */
	CString EncryptData( CSSLObject * SSLObject, CString s );
	/** */
	CString DecryptData( CSSLObject * SSLObject, CString s );

	/* */
	RSA * m_pRSA;
	/** */
	int * m_pRandBuffer;
};

#endif
